pub fn check_ffmpeg() -> Result<FfmpegVersion>Expand description
Run ffmpeg -version and parse the version line. Returns an error if the
binary is not found or the version is too old.
pub fn check_ffmpeg() -> Result<FfmpegVersion>Run ffmpeg -version and parse the version line. Returns an error if the
binary is not found or the version is too old.