Structs
- Encode
Job - Parameters for a single encode.
- Encode
Result - Output of a completed encode.
- Format
Info - Probe
Cache - Thread-safe probe result cache to avoid redundant ffprobe calls.
- Probe
Result - Progress
- Real-time encoding progress info parsed from FFmpeg.
- Resolution
- Video resolution.
- Stream
Info
Enums
- Codec
- Supported video codec.
- Rate
Control Mode - Rate control mode for encoding.
Constants
Functions
- encode
- Runs an FFmpeg encode job. Progress updates are sent on the channel if provided.
- extract
- Copies a segment of a video file without re-encoding.
- ffmpeg_
path - Returns the path to the ffmpeg binary.
- ffprobe_
path - Returns the path to the ffprobe binary.
- probe
- Runs ffprobe on the given file and returns parsed results.